/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package libcore.mmodule.libart;

import libcore.mmodule.simple.DemoSimpleClass;

/**
 * A class that provides:
 * <ul>
 * <li>A method within core-libart for the core-simple mmodule to depend on,
 * and a method that depends on the core-simple mmodule thereby demonstrating a
 * bi-directional, intra-module dependency.</li>
 * <li>A "core platform API" method for use by higher-level code.</li>
 * </ul>
 *
 * @hide
 */
@libcore.api.CorePlatformApi
@libcore.api.IntraCoreApi
public class DemoLibartClass {

    private DemoLibartClass() {}

    /**
     * A method that depends on the simple mmodule to work.
     */
    @libcore.api.IntraCoreApi
    public static String intraCoreDependencyMethod() {
        // Delegate to core-simple code to implement the method.
        return DemoSimpleClass.simpleMethod();
    }

    /**
     * A simple method that has no native or data file dependencies but is part of the intra-core
     * mmodule API contract.
     */
    @libcore.api.IntraCoreApi
    public static String simpleMethod() {
        return "Hello World";
    }

    /**
     * A core platform API method provided to higher-level code in the Android software stack.
     */
    @libcore.api.CorePlatformApi
    public static String corePlatformApiMethod() {
        return "Hello World";
    }

    /**
     * A method that is public but not part of either the intra-core or core platform API
     * contracts, i.e. it cannot be used from the rest of the platform or another core mmodule.
     */
    public static String hiddenMethod() {
        return "Hello World";
    }
}
